Coverage for pygeodesy/geodesicx/__init__.py: 100%

1

2# -*- coding: utf-8 -*-

3

4 u'''A pure Python version of I{Karney}'s C++ classes U{GeodesicExact

5<https://GeographicLib.SourceForge.io/C++/doc/classGeographicLib_1_1GeodesicExact.html>}

6 and U{GeodesicLineExact

7<https://GeographicLib.SourceForge.io/C++/doc/classGeographicLib_1_1GeodesicLine.html>}.

8

9 For more details, see the C++ U{GeographicLib<https://GeographicLib.SourceForge.io/C++/doc/index.html>}

10 documentation, especially the U{Class List<https://GeographicLib.SourceForge.io/C++/doc/annotated.html>}

11 and the background information at U{Geodesics on an ellipsoid of revolution

12<https://GeographicLib.SourceForge.io/C++/doc/geodesic.html#geodseries>}.

13

14 Also, compare C{GeodesicExact} and C{GeodesicLineExact} to I{standard} classes C{Geodesic}

15 respectively C{GeodesicLine} from I{Karney}'s Python implementation U{geographiclib

16<https://GeographicLib.SourceForge.io/C++/doc/other.html#python>}, see modules

17 L{pygeodesy.geodesicw} and L{pygeodesy.karney}.

18'''

19

20 from pygeodesy.geodesicx.gx import GeodesicExact, GeodesicLineExact # noqa: F401

21 from pygeodesy.geodesicx.gxarea import GeodesicAreaExact, PolygonArea # noqa: F401

22 from pygeodesy.karney import Caps, GeodesicError

23 from pygeodesy.lazily import _ALL_DOCS, _ALL_LAZY

24

25 __all__ = _ALL_LAZY.geodesicx + _ALL_DOCS(Caps, GeodesicError)

26 __version__ = '25.12.23'

27

28# **) MIT License

29#

30# Copyright (C) 2016-2026 -- mrJean1 at Gmail -- All Rights Reserved.

31#

32# Permission is hereby granted, free of charge, to any person obtaining a

33# copy of this software and associated documentation files (the "Software"),

34# to deal in the Software without restriction, including without limitation

35# the rights to use, copy, modify, merge, publish, distribute, sublicense,

36# and/or sell copies of the Software, and to permit persons to whom the

37# Software is furnished to do so, subject to the following conditions:

38#

39# The above copyright notice and this permission notice shall be included

40# in all copies or substantial portions of the Software.

41#

42# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS

43# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,

44# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL

45# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR

46# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,

47# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR

48# OTHER DEALINGS IN THE SOFTWARE.